@@ -1,12 +1,16 @@
 # fully internal function
 # given a data.frame try to infer
-# what kind of data we're dealing with
+# what kind of meta-analysis data we're dealing with
 
-detect_input_type <- function(data, group, treatment, outcome) {
+detect_input_type <- function(data,
+                              group="group",
+                              treatment="treatment",
+                              outcome="outcome") {
   # if(class == "baggr_data")
   if(!("data.frame" %in% class(data)))
     stop("Can't detect input type because it's not data.frame")
 
+  # Summary data -----
   if("tau" %in% names(data) && "se" %in% names(data)){
     if("treatment" %in% names(data))
       return("pool_narrow") #will need conversion
@@ -18,6 +22,10 @@ detect_input_type <- function(data, group, treatment, outcome) {
                       names(data)))))
     return("pool_wide")
 
+  if(check_columns_binary(data, stop = FALSE))
+    return("pool_binary")
+
+  # Individual-level data -----
   if(!is.null(data[[group]])){
     if(nrow(data) > length(unique(data[[group]]))){
       if(is_binary(data[[outcome]]))
@@ -26,5 +34,7 @@ detect_input_type <- function(data, group, treatment, outcome) {
         return("individual")
     }
   }
+
+  # Shrug emoji -----
   return("unknown")
 }
